@@ -156,7 +156,8 @@ if (version_compare(PHP_VERSION, "5.4.0", "<")) {
 	if (get_magic_quotes_gpc()) {
 		$in = array(&$_GET, &$_POST, &$_COOKIE);
 
-		while (list($k, $v) = each($in)) {
+		$_in = $in;
+		foreach ($in as $k => $v) {
 			foreach ($v as $key => $val) {
 				if (!is_array($val)) {
 					$in[$k][$key] = stripslashes($val);
@@ -563,6 +564,8 @@ if (Settings::Get('system.mail_use_smtp')) {
 	$mail->Password = Settings::Get('system.mail_smtp_passwd');
 	if (Settings::Get('system.mail_smtp_usetls')) {
 		$mail->SMTPSecure = 'tls';
+	} else {
+		$mail->SMTPAutoTLS = false;
 	}
 	$mail->Port = Settings::Get('system.mail_smtp_port');
 }
