@@ -78,34 +78,37 @@ class apache extends HttpConfigBase
 		}
 		$vhosts_filename = makeCorrectFile($vhosts_folder . '/05_froxlor_dirfix_nofcgid.conf');
 
-		if (Settings::Get('system.mod_fcgid') == '1' || Settings::Get('phpfpm.enabled') == '1') {
-			// if we use fcgid or php-fpm we don't need this file
-			if (file_exists($vhosts_filename)) {
-				$this->logger->logAction(CRON_ACTION, LOG_NOTICE, 'apache::_createStandardDirectoryEntry: unlinking ' . basename($vhosts_filename));
-				unlink(makeCorrectFile($vhosts_filename));
-			}
+		if (! isset($this->virtualhosts_data[$vhosts_filename])) {
+			$this->virtualhosts_data[$vhosts_filename] = '';
+		}
+
+		$this->virtualhosts_data[$vhosts_filename] .= '  <Directory "' . makeCorrectDir(Settings::Get('system.documentroot_prefix')) . '">' . "\n";
+
+		// check for custom values, see #1638
+		$custom_opts = Settings::Get('system.apacheglobaldiropt');
+		if (! empty($custom_opts)) {
+			$this->virtualhosts_data[$vhosts_filename] .= $custom_opts . "\n";
 		} else {
-			if (! isset($this->virtualhosts_data[$vhosts_filename])) {
-				$this->virtualhosts_data[$vhosts_filename] = '';
-			}
-
-			$this->virtualhosts_data[$vhosts_filename] .= '  <Directory "' . makeCorrectDir(Settings::Get('system.documentroot_prefix')) . '">' . "\n";
-
-			// check for custom values, see #1638
-			$custom_opts = Settings::Get('system.apacheglobaldiropt');
-			if (! empty($custom_opts)) {
-				$this->virtualhosts_data[$vhosts_filename] .= $custom_opts . "\n";
+			// >=apache-2.4 enabled?
+			if (Settings::Get('system.apache24') == '1') {
+				$this->virtualhosts_data[$vhosts_filename] .= '    Require all granted' . "\n";
+				$this->virtualhosts_data[$vhosts_filename] .= '    AllowOverride All' . "\n";
 			} else {
-				// >=apache-2.4 enabled?
-				if (Settings::Get('system.apache24') == '1') {
-					$this->virtualhosts_data[$vhosts_filename] .= '    Require all granted' . "\n";
-					$this->virtualhosts_data[$vhosts_filename] .= '    AllowOverride All' . "\n";
-				} else {
-					$this->virtualhosts_data[$vhosts_filename] .= '    Order allow,deny' . "\n";
-					$this->virtualhosts_data[$vhosts_filename] .= '    allow from all' . "\n";
-				}
+				$this->virtualhosts_data[$vhosts_filename] .= '    Order allow,deny' . "\n";
+				$this->virtualhosts_data[$vhosts_filename] .= '    allow from all' . "\n";
+			}
+		}
+		$this->virtualhosts_data[$vhosts_filename] .= '  </Directory>' . "\n";
+
+		$ocsp_cache_filename = makeCorrectFile($vhosts_folder . '/03_froxlor_ocsp_cache.conf');
+		if (Settings::Get('system.use_ssl') == '1' && Settings::Get('system.apache24') == 1) {
+			$this->virtualhosts_data[$ocsp_cache_filename] = 'SSLStaplingCache ' .
+					Settings::Get('system.apache24_ocsp_cache_path') . "\n";
+		} else {
+			if (file_exists($ocsp_cache_filename)) {
+				$this->logger->logAction(CRON_ACTION, LOG_NOTICE, 'apache::_createStandardDirectoryEntry: unlinking ' . basename($ocsp_cache_filename));
+				unlink(makeCorrectFile($ocsp_cache_filename));
 			}
-			$this->virtualhosts_data[$vhosts_filename] .= '  </Directory>' . "\n";
 		}
 	}
 
@@ -242,7 +245,7 @@ class apache extends HttpConfigBase
 								'adminid' => 1, /* first admin-user (superadmin) */
 								'mod_fcgid_starter' => - 1,
 								'mod_fcgid_maxrequests' => - 1,
-								'guid' => Settings::Get('phpfpm.vhost_httpuser'),
+								'guid' => Settings::Get('system.mod_fcgid_httpuser'),
 								'openbasedir' => 0,
 								'email' => Settings::Get('panel.adminmail'),
 								'loginname' => 'froxlor.panel',
@@ -423,6 +426,9 @@ class apache extends HttpConfigBase
 							$this->virtualhosts_data[$vhosts_filename] .= ' SSLEngine On' . "\n";
 							$this->virtualhosts_data[$vhosts_filename] .= ' SSLProtocol -ALL +TLSv1 +TLSv1.2' . "\n";
 							if (Settings::Get('system.apache24') == '1') {
+								if (Settings::Get('system.http2_support') == '1') {
+									$this->virtualhosts_data[$vhosts_filename] .= ' Protocols h2 http/1.1' . "\n";
+								}
 								$this->virtualhosts_data[$vhosts_filename] .= ' SSLCompression Off' . "\n";
 							}
 							// this makes it more secure, thx to Marcel (08/2013)
@@ -504,7 +510,7 @@ class apache extends HttpConfigBase
 			// This vHost has PHP enabled and we are using the regular mod_php
 			$cmail = getCustomerDetail($domain['customerid'], 'email');
 			$php_options_text .= '  php_admin_value sendmail_path "/usr/sbin/sendmail -t -f '.$cmail.'"' . PHP_EOL;
-			
+
 			if ($domain['openbasedir'] == '1') {
 				if ($domain['openbasedir_path'] == '1' || strstr($domain['documentroot'], ":") !== false) {
 					$_phpappendopenbasedir = appendOpenBasedirPath($domain['customerroot'], true);
@@ -858,7 +864,10 @@ class apache extends HttpConfigBase
 				$vhost_content .= '  SSLEngine On' . "\n";
 				$vhost_content .= '  SSLProtocol -ALL +TLSv1 +TLSv1.2' . "\n";
 				if (Settings::Get('system.apache24') == '1') {
-					$vhost_content .= ' SSLCompression Off' . "\n";
+					if (isset($domain['http2']) && $domain['http2'] == '1') {
+						$vhost_content .= ' Protocols h2 http/1.1' . "\n";
+					}
+					$vhost_content .= '  SSLCompression Off' . "\n";
 				}
 				// this makes it more secure, thx to Marcel (08/2013)
 				$vhost_content .= '  SSLHonorCipherOrder On' . "\n";
@@ -878,6 +887,12 @@ class apache extends HttpConfigBase
 					$vhost_content .= '  SSLCertificateChainFile ' . makeCorrectFile($domain['ssl_cert_chainfile']) . "\n";
 				}
 
+				if (Settings::Get('system.apache24') == '1' && isset($domain['ocsp_stapling']) &&
+						$domain['ocsp_stapling'] == '1')
+				{
+					$vhost_content .= '  SSLUseStapling on' . PHP_EOL;
+				}
+
 				if ($domain['hsts'] >= 0) {
 					$vhost_content .= '  <IfModule mod_headers.c>' . "\n";
 					$vhost_content .= '    Header always set Strict-Transport-Security "max-age=' . $domain['hsts'];
