@@ -196,7 +196,7 @@ class nginx extends HttpConfigBase
 					}
 				}
 
-				$http2 = $ssl_vhost == true && Settings::Get('system.nginx_http2_support') == '1';
+				$http2 = $ssl_vhost == true && Settings::Get('system.http2_support') == '1';
 
 				/**
 				 * this HAS to be set for the default host in nginx or else no vhost will work
@@ -418,7 +418,7 @@ class nginx extends HttpConfigBase
 				$_vhost_content .= $this->processSpecialConfigTemplate($ipandport['default_vhostconf_domain'], $domain, $domain['ip'], $domain['port'], $ssl_vhost) . "\n";
 			}
 
-            $http2 = $ssl_vhost == true && Settings::Get('system.nginx_http2_support') == '1';
+			$http2 = $ssl_vhost == true && (isset($domain['http2']) && $domain['http2'] == '1');
 
             $vhost_content .= "\t" . 'listen ' . $ipport . ($ssl_vhost == true ? ' ssl' : '') . ($http2 == true ? ' http2' : '') . ';' . "\n";
 		}
@@ -634,6 +634,14 @@ class nginx extends HttpConfigBase
 					}
 					$sslsettings .= '";' . "\n";
 				}
+
+				if ((isset($domain_or_ip['ocsp_stapling']) && $domain_or_ip['ocsp_stapling'] == "1") ||
+						(isset($domain_or_ip['letsencrypt']) && $domain_or_ip['letsencrypt'] == "1") ) {
+					$sslsettings .= "\t" . 'ssl_stapling on;' . "\n";
+					$sslsettings .= "\t" . 'ssl_stapling_verify on;' . "\n";
+					$sslsettings .= "\t" . 'ssl_trusted_certificate ' .
+							makeCorrectFile($domain_or_ip['ssl_cert_file']) . ';' . "\n";
+				}
 			}
 		}
 
@@ -711,6 +719,11 @@ class nginx extends HttpConfigBase
 								if ($single['path'] == '/') {
 									$path_options .= "\t\t" . 'auth_basic            "' . $single['authname'] . '";' . "\n";
 									$path_options .= "\t\t" . 'auth_basic_user_file  ' . makeCorrectFile($single['usrf']) . ';' . "\n";
+									if ($domain['phpenabled_customer'] == 1 && $domain['phpenabled_vhost'] == '1') {
+										$path_options .= "\t\t" . 'index    index.php index.html index.htm;' . "\n";
+									} else {
+										$path_options .= "\t\t" . 'index    index.html index.htm;' . "\n";
+									}
 									$path_options .= "\t\t" . 'location ~ ^(.+?\.php)(/.*)?$ {' . "\n";
 									$path_options .= "\t\t\t" . 'try_files ' . $domain['nonexistinguri'] . ' @php;' . "\n";
 									$path_options .= "\t\t" . '}' . "\n";
@@ -768,6 +781,11 @@ class nginx extends HttpConfigBase
 						$path_options .= "\t" . 'location ' . makeCorrectDir($single['path']) . ' {' . "\n";
 						$path_options .= "\t\t" . 'auth_basic            "' . $single['authname'] . '";' . "\n";
 						$path_options .= "\t\t" . 'auth_basic_user_file  ' . makeCorrectFile($single['usrf']) . ';' . "\n";
+						if ($domain['phpenabled_customer'] == 1 && $domain['phpenabled_vhost'] == '1') {
+							$path_options .= "\t\t" . 'index    index.php index.html index.htm;' . "\n";
+						} else {
+							$path_options .= "\t\t" . 'index    index.html index.htm;' . "\n";
+						}
 						$path_options .= "\t\t" . 'location ~ ^(.+?\.php)(/.*)?$ {' . "\n";
 						$path_options .= "\t\t\t" . 'try_files ' . $domain['nonexistinguri'] . ' @php;' . "\n";
 						$path_options .= "\t\t" . '}' . "\n";
